.. include global.rst

.. meta::
    :github_url: https://github.com/davidhalter/jedi

Jedi - an awesome autocompletion, static analysis and refactoring library for Python
====================================================================================

.. image:: https://img.shields.io/github/stars/davidhalter/jedi.svg?style=social&label=Star&maxAge=2592000
    :target: https://github.com/davidhalter/jedi
    :alt: GitHub stars

.. image:: http://isitmaintained.com/badge/open/davidhalter/jedi.svg
    :target: https://github.com/davidhalter/jedi/issues
    :alt: The percentage of open issues and pull requests

.. image:: http://isitmaintained.com/badge/resolution/davidhalter/jedi.svg
    :target: https://github.com/davidhalter/jedi/issues
    :alt: The resolution time is the median time an issue or pull request stays open.

.. image:: https://github.com/davidhalter/jedi/workflows/ci/badge.svg?branch=master
    :target: https://github.com/davidhalter/jedi/actions
    :alt: Tests

.. image:: https://coveralls.io/repos/davidhalter/jedi/badge.svg?branch=master
    :target: https://coveralls.io/r/davidhalter/jedi
    :alt: Coverage status

.. image:: https://pepy.tech/badge/jedi
    :target: https://pepy.tech/project/jedi
    :alt: PyPI Downloads

`Github Repository <https://github.com/davidhalter/jedi>`_

.. automodule:: jedi

Autocompletion can for example look like this in jedi-vim:

.. figure:: _screenshots/screenshot_complete.png


.. _toc:

Docs
----

.. toctree::
   :maxdepth: 1

   docs/usage
   docs/features
   docs/api
   docs/api-classes
   docs/installation
   docs/settings
   docs/development
   docs/testing
   docs/acknowledgements
   docs/changelog


.. _resources:

Resources
---------

If you want to stay **up-to-date** with releases, please **subscribe** to this
mailing list: https://groups.google.com/g/jedi-announce. To subscribe you can
simply send an empty email to ``jedi-announce+subscribe@googlegroups.com``.

- `Source Code on Github <https://github.com/davidhalter/jedi>`_
- `Python Package Index <https://pypi.python.org/pypi/jedi/>`_
